@@ -1,4 +1,4 @@
-set_pkg_opts <- function(..., opt_list = NULL) {
+set_pkg_opts <- function(..., opt_list=NULL) {
   pkg_opts <- c(pairlist(...), as.pairlist(opt_list))
 
   if (is.null(pkg_opts)) {
@@ -18,9 +18,8 @@ set_pkg_opts <- function(..., opt_list = NULL) {
 
 .onLoad <- function(libname, pkgname) {
   set_pkg_opts(
-    ggdistribute.font = "",
-    ggdistribute.geom.defaults = list(edited = FALSE),
-    ggdistribute.geom.edits = list())
+    ggdistribute.font="", ggdistribute.geom.defaults=list(edited=FALSE),
+    ggdistribute.geom.edits=list())
   invisible()
 }
 
